package BPpackage;
 
/*
 * Player.java is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * R. Earle Harris (evsiz@this-voice.org) copyrighted 2014
 *
 */


import android.app.Activity;
import android.app.Dialog;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.ServiceConnection;
import android.media.AudioManager;
import android.media.AudioManager.OnAudioFocusChangeListener;
import android.os.Bundle;
import android.os.IBinder;
import android.view.Gravity;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.Window;
import android.widget.Button;
import android.widget.ImageButton;
import android.widget.TextView;
import android.widget.Toast;
import java.io.File;
import java.util.ArrayList;
import java.util.Collections;
import org.this_voice.simplest.AudioService.LocalBinder;


public class Player extends Activity implements AudioManager.OnAudioFocusChangeListener {

	public AudioManager audioManager = null;
	public ArrayList<File> audio = null;
	public ImageButton next;
	public ImageButton pause;
	public ImageButton prev;
	public ImageButton toggle;
	public Integer pos = 0;
	public PRAFileHandler fhandler = new PRAFileHandler(this);
    public AudioService mService;
    public TextView title;
    public boolean mBound = false;
    public boolean paused = false;
    public boolean started = false;
    public boolean random = false;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);

		audioManager = (AudioManager) getSystemService(Context.AUDIO_SERVICE);
		audioManager.requestAudioFocus(this, AudioManager.STREAM_MUSIC, AudioManager.AUDIOFOCUS_GAIN);
		requestWindowFeature(Window.FEATURE_NO_TITLE);
		setContentView(R.layout.activity_result);
		findViews();

		if (android.os.Build.VERSION.SDK_INT > 10) {
			this.setFinishOnTouchOutside(false);
		}

		toggle.setBackgroundResource(R.drawable.icon_av_play);
		pause.setBackgroundResource(R.drawable.icon_av_pause);
		Intent i = getIntent();

		audio = (ArrayList<File>) i.getSerializableExtra("AUDIO");
		ArrayList<String> tmpa = new ArrayList<String>();
		for (File f : audio){
			tmpa.add(f.toString());
		}

		int pos  = i.getIntExtra("POS", 0);
		if (pos == -1){
			Collections.shuffle(tmpa);
			random = true;
		} else {
			if (pos != 0){
				String tmp = "";
				for (int j = 0; j < pos; j++){
					tmp = tmpa.get(0);
					tmpa.remove(0);
					tmpa.add(tmp);
				}
			}
		}
		fhandler.writeListToFile(tmpa,"playlist.txt");

        Intent intent = new Intent(this, AudioService.class);
        bindService(intent, mConnection, Context.BIND_AUTO_CREATE);
	}


	private void findViews() {
		title = (TextView) findViewById(R.id.title);
		next = (ImageButton) findViewById(R.id.next);
		next.setBackgroundResource(R.drawable.icon_av_next);
		toggle = (ImageButton) findViewById(R.id.toggle);
		toggle.setBackgroundResource(R.drawable.icon_av_play);
		pause = (ImageButton) findViewById(R.id.pause);
		pause.setBackgroundResource(R.drawable.icon_av_pause);
		prev = (ImageButton) findViewById(R.id.prev);
		prev.setBackgroundResource(R.drawable.icon_av_previous);
	}

    public void startStop(View v) {
        if (mBound) {
			started = !started;
			if (started){
				mService.start(random);
				toggle.setBackgroundResource(R.drawable.icon_stop);
			} else {
				final Dialog dialog = new Dialog(this);
				dialog.requestWindowFeature(Window.FEATURE_NO_TITLE);
				dialog.setContentView(R.layout.alert_two);
				TextView t = (TextView) dialog.findViewById(R.id.dTitle);
				t.setText("Simplest");
				TextView m = (TextView) dialog.findViewById(R.id.dMessage);
				m.setText("Back to lists or exit app. Backbutton cancels.");
				
				Button pos = (Button) dialog.findViewById(R.id.dPos);
				pos.setText("Lists");
				pos.setOnClickListener(new OnClickListener() {
						@Override
							public void onClick(View v) {
							mService.stop();
							toggle.setBackgroundResource(R.drawable.icon_av_play);
							dialog.dismiss();
							okayBye("lists");
						}
					});
				
				Button neg = (Button) dialog.findViewById(R.id.dNeg);
				neg.setText("Exit");
				neg.setOnClickListener(new OnClickListener() {
						@Override
							public void onClick(View v) {
							mService.stop();
							toggle.setBackgroundResource(R.drawable.icon_av_play);
							dialog.dismiss();
							okayBye("exit");
						}
					});
				
				dialog.show();
			}
		}
	}

	private void okayBye(String data){
		Intent intent = new Intent();
		intent.putExtra("DATA", data);
		setResult(RESULT_OK, intent); 
		finish();
	}

    public void pauseResume(View v) {
        if (mBound) {
			paused = !paused;
			if (paused){
				mService.pause();
				pause.setBackgroundResource(R.drawable.icon_av_play);
			} else {
				mService.resume();
				pause.setBackgroundResource(R.drawable.icon_av_pause);
			}
		}
	}

    public void next(View v) {
        if (mBound) {
			mService.next();
		}
	}

    public void prev(View v) {
        if (mBound) {
			mService.prev();
		}
	}

    @Override
    protected void onDestroy() {
        super.onDestroy();
        if (mBound) {
            unbindService(mConnection);
            mBound = false;
        }
    }

	@Override
    protected void onNewIntent(Intent intent) {
        super.onNewIntent(intent);
    }

    /** Defines callbacks for service binding, passed to bindService() */
    private ServiceConnection mConnection = new ServiceConnection() {

        @Override
		public void onServiceConnected(ComponentName className, IBinder service) {
            LocalBinder binder = (LocalBinder) service;
            mService = (AudioService) binder.getService();
            mBound = true;
        }
			
		@Override
			public void onServiceDisconnected(ComponentName arg0) {
			mBound = false;
		}
		};
		


	@Override
	public void onBackPressed() {
		toaster("Press Home button to leave player running",Toast.LENGTH_LONG);
	}


	public void toaster(String text, int length) {
		Toast t = Toast.makeText(this, text, length);
		t.setGravity(Gravity.CENTER, 0, 0);
		t.show();
	}

	public void onAudioFocusChange(int focusChange) {
		switch (focusChange) {
        case AudioManager.AUDIOFOCUS_GAIN:
            // resume playback
			mService.resume();
            break;

        case AudioManager.AUDIOFOCUS_LOSS:
            // Lost focus for an unbounded amount of time: stop playback and release media player
			mService.stop();
            break;

        case AudioManager.AUDIOFOCUS_LOSS_TRANSIENT:
            // Lost focus for a short time, but we have to stop
            // playback. We don't release the media player because playback
            // is likely to resume
            mService.pause();
            break;

        case AudioManager.AUDIOFOCUS_LOSS_TRANSIENT_CAN_DUCK:
            // Lost focus for a short time, but it's ok to keep playing
            // at an attenuated level
            mService.pause();
            break;
		}
	}

}
