package BPpackage;
 
/*
 * FTPJuju.java is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * R. Earle Harris (evsiz@this-voice.org) copyrighted 2014
 *
 */


import android.annotation.SuppressLint;
import android.app.AlertDialog;
import android.app.ListActivity;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.database.Cursor;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.net.Uri;
import android.os.AsyncTask;
import android.os.Bundle;
import android.os.Environment;
import android.os.StrictMode;
import android.provider.MediaStore.MediaColumns;
import android.view.LayoutInflater;
import android.view.MenuItem;
import android.view.View;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.AdapterView.OnItemLongClickListener;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.Toast;
import it.sauronsoftware.ftp4j.FTPClient;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.StringTokenizer;

@SuppressLint("NewApi")
public class FTPJuju extends ListActivity {

	public final int PUT = -1;
	public final int CHS = 0;
	public final int DEL = 1;
	public final int DLD = 2;

	public PRAFileHandler fhandler = null;
	public ArrayList<String> files2upload = new ArrayList<String>();
	public Intent intent;
	public Map<String, String[]> bookmarks = new HashMap<String, String[]>();
	public String fname2upload = "";
	public String[] Bookmarks;
	public boolean exit = false;
	public int mode = -1;
	public TextView title;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);

		// override network on ui exception for DEL mode
		if (android.os.Build.VERSION.SDK_INT > 9) {
			StrictMode.ThreadPolicy policy = new StrictMode.ThreadPolicy.Builder()
					.permitAll().build();
			StrictMode.setThreadPolicy(policy);
		}

		fhandler = new PRAFileHandler(this);
		setContentView(R.layout.activity_ftpjuju);
		title = (TextView) findViewById(R.id.textTitle);

		intent = getIntent();
		fname2upload = intent.getStringExtra("FILE");
		if ((fname2upload != null) && (!fname2upload.matches(""))) {
			mode = PUT;
			String[] tokens = fname2upload.split("/");
			String name = tokens[tokens.length - 1];
			title.setText("FTP: "+ name);
			files2upload.add(fname2upload);
		} else {
			mode = DEL;
		}

	}

	@Override
	public void onResume() {
		super.onResume();

		Bookmarks = loadBookmarks();
		setListAdapter(new ArrayAdapter<String>(this, R.layout.bookmark, Bookmarks));
		EdgeEffectListView listView = (EdgeEffectListView) getListView();
		listView.setTextFilterEnabled(true);

		listView.setOnItemClickListener(new OnItemClickListener() {
				public void onItemClick(AdapterView<?> parent, View view,
										int position, long id) {
					String server = (String) ((TextView) view).getText();
					if (!server.matches("")) {
						if (mode == PUT) {
							upload(server);
						} else {
							Toast.makeText(getApplicationContext(),
										   "Logging onto " + server, Toast.LENGTH_LONG).show();
							delete(server);
						}
					}
				}
			});
		
		final String[] menu_array = { 
			"Delete", 
			"Edit", 
		};

		final Context c = this;

		listView.setOnItemLongClickListener(new OnItemLongClickListener() {
		 
		    @Override 
			public boolean onItemLongClick(AdapterView parentView, View view, int position, long id) {
				final String server = ((TextView) view).getText().toString();
				if (server.matches("")) {
					return false;
				}

				LayoutInflater inflater = getLayoutInflater();
				final ArrayList<String> alist = new ArrayList<String>();
				for (int i = 0; i < menu_array.length; ++i) {
					alist.add(menu_array[i]);
				}
				
				AlertDialog.Builder builder = new AlertDialog.Builder(c);
				final ArrayAdapter adapter = new ArrayAdapter(c, R.layout.pra_list_item, alist);
				builder.setView(inflater.inflate(R.layout.list_context_menu, null))
					.setAdapter(adapter, new DialogInterface.OnClickListener() {
					@Override
					public void onClick(DialogInterface dialog, int which) {
						String result = (String) adapter.getItem(which);
						if (result.matches("Delete")){
							deleteBookmark(server);
						} else if (result.matches("Edit")){
							editBookmark(server);
						}
						
					}
						})
					.create()
					.show();
				return true;
			}
			});
	}


	// if PUT, shortpress uploads to chosen server
	public void upload(String server) {
		if (!exit) {
			ConnectivityManager cm = (ConnectivityManager) getBaseContext()
					.getSystemService(Context.CONNECTIVITY_SERVICE);

			NetworkInfo i = cm.getActiveNetworkInfo();
			if ((i == null) || (!i.isConnected())) {
				Toast.makeText(getBaseContext(),
						"Error: No connection to Internet", Toast.LENGTH_SHORT).show();
			} else {
				String[] tmp = bookmarks.get(server);
				for (String file : files2upload) {
					Toast.makeText(getApplicationContext(),
							"Uploading " + file, Toast.LENGTH_SHORT)
							.show();
					String[] data = { file, tmp[0], tmp[1], tmp[2], tmp[3],
							tmp[4] };
					new ServerAsyncTask().execute(data);
				}
			}
			this.finish();
		}
	}

	// else shortpress opens bkmk for choosing file
	static final int FILE_REQUEST = 2;

	public void delete(String server) {
		if (!exit) {
			ConnectivityManager cm = (ConnectivityManager) getBaseContext()
					.getSystemService(Context.CONNECTIVITY_SERVICE);

			NetworkInfo i = cm.getActiveNetworkInfo();
			if ((i == null) || (!i.isConnected())) {
				Toast.makeText(getBaseContext(),
						"Error: No connection to Internet", Toast.LENGTH_SHORT).show();
			} else {
				String[] tmp = bookmarks.get(server);
				Intent intent = new Intent(this, ChooserActivity.class);
				intent.putExtra("USER", tmp[0]);
				intent.putExtra("PSWD", tmp[1]);
				intent.putExtra("SRVR", tmp[2]);
				intent.putExtra("PORT", tmp[3]);
				intent.putExtra("PATH", tmp[4]);
				intent.putExtra("MODE", DEL);
				startActivityForResult(intent, FILE_REQUEST);
			}
		}
	}

	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		if (requestCode == FILE_REQUEST) {
			String result = data.getStringExtra("RESULT_STRING");
			Toast.makeText(getBaseContext(), result, Toast.LENGTH_SHORT).show();
		}
	}


	public void editBookmark(String server) {
		String[] tmp = bookmarks.get(server);
		Intent editserver = new Intent(this, AddServerActivity.class);
		editserver.putExtra("EDIT", 1);
		editserver.putExtra("NAME", server);
		editserver.putExtra("USER", tmp[0]);
		editserver.putExtra("PSWD", tmp[1]);
		editserver.putExtra("SRVR", tmp[2]);
		editserver.putExtra("PORT", tmp[3]);
		editserver.putExtra("PATH", tmp[4]);
		startActivity(editserver);
	}

	public void deleteBookmark(String server) {
		AlertDialog.Builder builder = new AlertDialog.Builder(this);
		builder.setTitle("Delete " + server + "?");
		final String srvr = server;
		builder.setPositiveButton("Delete",
				new DialogInterface.OnClickListener() {
					@Override
					public void onClick(DialogInterface dialog, int which) {
						fhandler.removeLineByToken0("ftpjuju.txt", srvr, ":");
						onResume();
					}
				});
		builder.setNegativeButton("Cancel",
				new DialogInterface.OnClickListener() {
					@Override
					public void onClick(DialogInterface dialog, int which) {
						dialog.cancel();
					}
				});

		builder.show();
	}


	/**
	 * Utility methods
	 */

	/**
	 * called by newButton in activity_ftpjuju
	 */
	public void newBookmark(View view) {
		Intent addserver = new Intent(this, AddServerActivity.class);
		startActivity(addserver);
	}

	/**
	 * Converts content uri to filename
	 *
	 * @param uri
	 * @return string of filename
	 */
	private String uri2fname(Uri uri) {
		String[] proj = { MediaColumns.DATA };
		Cursor cursor = managedQuery(uri, proj, null, null, null);
		int column_index = cursor.getColumnIndexOrThrow(MediaColumns.DATA);
		cursor.moveToFirst();
		return cursor.getString(column_index);
	}

	/**
	 * Read up ftpjuju.txt into bookmarks map
	 *
	 * @return
	 */
	private String[] loadBookmarks() {
		List<String> alist = new ArrayList<String>();
		String[] marks = fhandler.getFileAsArray("ftpjuju.txt");
		for (String s : marks) {
			StringTokenizer st = new StringTokenizer(s, ":");
			String[] bkmk = { "", "", "", "", "" };
			String name = st.nextToken(); // name
			bkmk[0] = st.nextToken(); // user
			bkmk[1] = st.nextToken(); // pswd
			bkmk[2] = st.nextToken(); // srvr
			bkmk[3] = st.nextToken(); // port
			bkmk[4] = st.nextToken(); // path
			bookmarks.put(name, bkmk);
			alist.add(name);
		}

		Collections.sort(alist);
		String[] list = new String[alist.size()];
		alist.toArray(list);
		return list;

	}

	/**
	 * upload fname2upload async off ui thread
	 */

	private class ServerAsyncTask extends AsyncTask<String, Void, String> {
		/**
		 * The system calls this to perform work in a worker thread and delivers
		 * it the parameters given to AsyncTask.execute()
		 */
		@Override
		protected String doInBackground(String... data) {
			FTPClient client = new FTPClient();
			String msg = "";

			if (!exit) {
				try { // connect
					client.connect(data[3].toString(),
							Integer.parseInt(data[4].toString()));
				} catch (Exception e) {
					e.printStackTrace();
					msg = "Failed connect with " + data[3];
					exit = true;
				}
			}

			if (!exit) {
				try { // login
					client.login(data[1].toString(), data[2].toString());
				} catch (Exception e) {
					msg = "Failed login as " + data[1];
					exit = true;
				}
			}

			if (!exit) {
				try { // cd to bmPath
					client.changeDirectory(data[5].toString());
				} catch (Exception e) {
					msg = "Failed cd into " + data[5];
					exit = true;
				}
			}

			if (!exit) {
				try { // upload
					client.upload(new java.io.File(data[0].toString()));
				} catch (Exception e) {
					msg = "Failed upload of " + data[0];
					exit = true;
				}
			}

			if (!exit) {
				try { // disconnect
					client.disconnect(true);
				} catch (Exception e) {
					;// empty
				}
			}

			if (!exit) {
				msg = "Uploaded " + data[0];
			}
			return msg;
		}

		/**
		 * The system calls this to perform work in the UI thread and delivers
		 * the result from doInBackground()
		 */
		@Override
		protected void onPostExecute(String result) {
			Toast.makeText(getBaseContext(), result, Toast.LENGTH_SHORT).show();
		}
	};// class


}
