package BPpackage.adapters;
 
/*
 * ImagesAdapter.java is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * R. Earle Harris (evsiz@this-voice.org) copyrighted 2014
 *
 */


import android.content.Context;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.ImageView;
import java.security.InvalidParameterException;

/**
 * Simple adapter that shows full bleed images (given some set of image drawable
 * resource id) yet is backed by a set of titles too, which is the data object
 * returned in {@link #getItem(int)}.
 * 
 * @author Eric Kok
 */

public class ImagesAdapter extends BaseAdapter {

	private final Context context;
	private final int[] images;
	private final String[] titles;

	public ImagesAdapter(Context context, int[] images, String[] titles) {
		this.context = context;
		this.images = images;
		this.titles = titles;
		if (titles.length != images.length)
			throw new InvalidParameterException(
					"List of images should be of equal length as the list of titles.");
	}

	@Override
	public int getCount() {
		return images.length;
	}

	@Override
	public Object getItem(int position) {
		return titles[position];
	}

	@Override
	public long getItemId(int position) {
		return position;
	}

	@Override
	public View getView(int position, View convertView, ViewGroup parent) {
		ImageView imageView = (ImageView) convertView;
		if (imageView == null) {
			imageView = new ImageView(context);
		}
		imageView.setAdjustViewBounds(true);
		imageView.setImageResource(images[position]);
		return imageView;
	}
}
