package BPpackage;
 
/*
 * BoilerPlate.java is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * R. Earle Harris (evsiz@this-voice.org) copyrighted 2014
 *
 */


import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Build;
import android.os.Bundle;
import android.os.Handler;
import android.preference.PreferenceManager;
import android.text.InputType;
import android.view.View.OnClickListener;
import android.view.View;
import android.view.Window;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.widget.Button;
import android.widget.EditText;
import android.widget.ImageButton;
import android.widget.ProgressBar;
import android.widget.TextView;
import android.widget.Toast;


public class BoilerPlate extends Activity {

	public SharedPreferences prefs;
	public PRAFileHandler fhandler = new PRAFileHandler(this);
	public Mu2 mu2 = new Mu2();
	public String[] pages;
	public int currentPage = 0;
	public int pageCount = 0;
	public int pageSize = 64;
	public int remainder;
	public int scale;
	public String[] bookArray;
	public boolean fan = true;

	public ReaderView wv;
	public ImageButton btnClose;
	public ImageButton btnEmail;
	public ImageButton btnHelp;
	public ImageButton btnGoto;
	public ProgressBar progressbar;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		getWindow().requestFeature(Window.FEATURE_PROGRESS);
		setContentView(R.layout.activity_reader);
		btnClose = (ImageButton) findViewById(R.id.btnClose);
		btnEmail = (ImageButton) findViewById(R.id.btnEmail);
		btnHelp = (ImageButton) findViewById(R.id.btnHelp);
		btnGoto = (ImageButton) findViewById(R.id.btnGoto);
		progressbar = (ProgressBar) findViewById(R.id.progressbar);

		wv = (ReaderView) findViewById(R.id.webview);
		wv.setScrollBarStyle(View.SCROLLBARS_INSIDE_OVERLAY);
		wv.getSettings().setBuiltInZoomControls(true);

		wv.setWebViewClient(new WebViewClient() {
			public boolean shouldOverrideUrlLoading(WebView view, String url) {
				view.loadUrl(url);
				return true;
			}
		});

		bookArray = fhandler.getAssetAsArray("EDAAT01.mu");
		int length = bookArray.length;
		pageCount = length / pageSize;
		remainder = length % pageSize;
		if (remainder != 0) {
			pageCount++;
		}
		pages = new String[pageCount + 1];
		progressbar.setMax(pageCount);
		progressbar.setProgress(0);

		wv.loadUrl("file:///android_asset/index.html");

		prefs = PreferenceManager.getDefaultSharedPreferences(this);
		currentPage = prefs.getInt("LastPage", 0);
		if (currentPage < 3) {
			Toast.makeText(this, "Swipe right to left to begin",
					Toast.LENGTH_LONG).show();
			Toast.makeText(this, "Double-tap screen to toggle menu",
					Toast.LENGTH_LONG).show();
		}
		new SimpleEula(this).show();
	}

	public void pagePrev() {
		currentPage = currentPage - 2;
		pageNext();
	}

	public void pageNext() {
		if (currentPage == pageCount) {
			return;
		}
		if (currentPage < 0){
			currentPage = 0;
		}
		scale = (int) (100 * wv.getScale());
		int i = (currentPage * pageSize);
		String page = "";
		currentPage++;
		if (pages[currentPage] != null) {
			page = pages[currentPage];
		} else {
			int size = pageSize;
			if (currentPage == pageCount) {
				size = remainder;
			}
			if (pageCount == 1) {
				i = 0;
				size = remainder;
			}
			for (int j = i; j < i + size; j++) {
				page = page + mu2.convert(bookArray[j]);
			}
			pages[currentPage] = page;
		}
		progressbar.setProgress(currentPage);
		wv.setInitialScale(scale);
		wv.loadData(page, "text/html;charset=utf-8", "utf-8");
	}

	public void toggleMenu() {
		fan = !fan;
		int i;
		if (fan) {
			i = View.GONE;
		} else {
			i = View.VISIBLE;
		}
		btnClose.setVisibility(i);
		btnEmail.setVisibility(i);
		btnHelp.setVisibility(i);
		btnGoto.setVisibility(i);
	}

	public void gotoPage(View view) {
		toggleMenu();
		String msg = "Current page: " + Integer.toString(currentPage) + " of "
				+ Integer.toString(pageCount);
		final Dialog dialog = new Dialog(this);
		dialog.requestWindowFeature(Window.FEATURE_NO_TITLE);
		dialog.setContentView(R.layout.alert_two_edit);
		TextView t = (TextView) dialog.findViewById(R.id.dTitle);
		t.setText("Go to page ...");
		TextView m = (TextView) dialog.findViewById(R.id.dMessage);
		m.setText(msg);
		final EditText e = (EditText) dialog.findViewById(R.id.dEdit);
		e.setInputType(InputType.TYPE_CLASS_NUMBER);

		Button pos = (Button) dialog.findViewById(R.id.dPos);
		pos.setText("Go");
		pos.setOnClickListener(new OnClickListener() {
			@Override
			public void onClick(View v) {
				int num = 0;
				try {
					num = Integer.parseInt(e.getText() .toString());
				} catch (NumberFormatException nfe) {
					// empty
				}
				if (num < 1) {
					num = 1;
				} else {
					if (num > pageCount) {
						num = pageCount;
					}
				}
				currentPage = num - 1;
				pageNext();
				dialog.dismiss();
			}
			});
		
		Button neg = (Button) dialog.findViewById(R.id.dNeg);
		neg.setText("Cancel");
		neg.setOnClickListener(new OnClickListener() {
				@Override
					public void onClick(View v) {
					dialog.dismiss();
				}
			});
		
		dialog.show();
	}

	public void showHelp(View view) {
		toggleMenu();
		final Dialog dialog = new Dialog(this);
		dialog.requestWindowFeature(Window.FEATURE_NO_TITLE);
		dialog.setContentView(R.layout.alert_note);
		TextView t = (TextView) dialog.findViewById(R.id.dTitle);
		t.setText(getString(R.string.app_name));
		TextView m = (TextView) dialog.findViewById(R.id.dNote);
		m.setText(getString(R.string.helper));
		Button ok = (Button) dialog.findViewById(R.id.dOK);
		ok.setText("Okay");
		ok.setOnClickListener(new OnClickListener() {
				@Override
					public void onClick(View v) {
					dialog.dismiss();
				}
			});
		dialog.show();
	}

	public void emailAuthor(View view) {
		toggleMenu();
		Intent emailIntent = new Intent(android.content.Intent.ACTION_SEND);
		String[] recipients = new String[] { "YOUR_EMAIL_HERE",
				"", };
		emailIntent.putExtra(android.content.Intent.EXTRA_EMAIL, recipients);
		emailIntent.putExtra(android.content.Intent.EXTRA_SUBJECT,
				"YOUR_SUBJECT_HERE");
		emailIntent.putExtra(android.content.Intent.EXTRA_TEXT,
				"\n\n\n\n\n\n\n\nI\'m on a " + Build.MANUFACTURER + " "
						+ Build.MODEL + " using Android "
						+ Build.VERSION.RELEASE);
		emailIntent.setType("text/plain");
		startActivity(Intent
				.createChooser(emailIntent, "Email YOU_HERE..."));

	}

	public void closeApp(View view) {
		okayBye();
	}

	public void okayBye() {
		SharedPreferences.Editor editor = prefs.edit();
		editor.putInt("LastPage", currentPage - 1);
		editor.commit();
		finish();
	}

	private boolean doubleBackPressedOnce = false;

	@Override
	public void onBackPressed() {
		if (doubleBackPressedOnce) {
			wv.clearCache(true);
			okayBye();
			return;
		}
		doubleBackPressedOnce = true;
		Toast.makeText(this, R.string.exit_bkbtn, Toast.LENGTH_SHORT).show();
		new Handler().postDelayed(new Runnable() {

			@Override
			public void run() {
				doubleBackPressedOnce = false;
			}
		}, 2000);
	}


}
