package BPpackage;
 
/*
 * BoilerPlate.java is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * R. Earle Harris (evsiz@this-voice.org) copyrighted 2014
 *
 */


import android.app.Activity;
import android.os.Bundle;
import android.view.Gravity;
import android.view.View;
import android.webkit.WebView;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.RadioButton;
import android.widget.TextView;
import android.widget.Toast;

import java.lang.IllegalAccessException;
import java.lang.IllegalArgumentException;
import java.lang.IllegalStateException;
import java.lang.Exception;
import java.lang.reflect.Field;
import java.lang.String;
import java.util.ArrayList;


public class BoilerPlate extends Activity {

    public Button next;
    public Button playPause;
    public Button prev;
    public Button restart;
    public CheckBox repeat;
    public RadioButton minusTen;
    public RadioButton minusTwenty;
    public RadioButton normal;
    public TextView title;
    public WebView webview;

    public boolean paused = true;
    public boolean playing = false;
    public boolean wasPlaying = false;
    public boolean repeating = true;
    public float speed = 1.0f;
	public int currentTrack = 0;

    public ArrayList<Integer> tracks;
    public WavTrack mTrack = null;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);

		// ui
        setContentView(R.layout.activity_boilerplate);
        findViews();
		prev.setBackgroundResource(R.drawable.icon_av_previous);
		playPause.setBackgroundResource(R.drawable.icon_av_play);
		next.setBackgroundResource(R.drawable.icon_av_next);
		restart.setBackgroundResource(R.drawable.icon_av_restart);
        repeat.setChecked(repeating);

        // track list
        tracks = new ArrayList<Integer>();
        Field[] fields = R.raw.class.getFields();
        for(Field f : fields)
        try {
            tracks.add(f.getInt(null));
        } catch (IllegalArgumentException e) {
        } catch (IllegalAccessException e) { }

	}

	private void findViews() {
		title = (TextView) findViewById(R.id.title);
		webview = (WebView) findViewById(R.id.webview);
		prev = (Button) findViewById(R.id.prev);
		playPause = (Button) findViewById(R.id.playPause);
		next = (Button) findViewById(R.id.next);
		normal = (RadioButton) findViewById(R.id.normal);
		minusTen = (RadioButton) findViewById(R.id.minusTen);
		minusTwenty = (RadioButton) findViewById(R.id.minusTwenty);
		repeat = (CheckBox) findViewById(R.id.repeat);
		restart = (Button) findViewById(R.id.restart);
	}

	public void toaster(String text, int length) {
		Toast t = Toast.makeText(this, text, length);
		t.setGravity(Gravity.CENTER, 0, 0);
		t.show();
	}

    public void trackPrev(View view){
   		playPause.setBackgroundResource(R.drawable.icon_av_pause);
		currentTrack--;
		if (currentTrack < 0) {
			currentTrack = tracks.size() - 1;
		}
		newTrack();
    }

    public void trackNext(View view){
   		playPause.setBackgroundResource(R.drawable.icon_av_pause);
		currentTrack++;
		if (currentTrack == tracks.size()) {
			currentTrack = 0;
		}
		newTrack();
    }

    public void isRepeating(View view){
        repeating = !repeating;
    }

	public void trackEnded(){
		if (repeating){
			newTrack();
		} else {
			paused = true;
			playing = false;
			mTrack.pause();
			mTrack.finished();
			mTrack = null;
		}
	}

	public void restart(View view){
		if (!playing){ return; }
  		playPause.setBackgroundResource(R.drawable.icon_av_pause);
		paused = false;
   		newTrack();
	}

	public void newTrack(){
		if ((playing) && (mTrack != null)){
			mTrack.pause();
			mTrack.finished();
		}
		mTrack = null;
		mTrack = new WavTrack(this, tracks.get(currentTrack), speed);
	}

    public void trackPlayPause(View view){
        paused = !paused;
        if ((paused) && (mTrack != null)){
    		playPause.setBackgroundResource(R.drawable.icon_av_play);
            mTrack.pause();
        } else {
    		playPause.setBackgroundResource(R.drawable.icon_av_pause);
            if (!playing){
                playing = true;
                newTrack();
            } else {
                mTrack.play();
            }
        }
    }

    public void onRadioButtonClicked(View view) {
        boolean checked = ((RadioButton) view).isChecked();
		if (mTrack == null){ return; }

        switch(view.getId()) {
            case R.id.normal:
                if (checked)
                    speed = 1.0f;
                break;
            case R.id.minusTen:
                if (checked)
                    speed = 0.92f;
                break;
            case R.id.minusTwenty:
                if (checked)
                    speed = 0.85f;
                break;
        }
		mTrack.changeSpeed(speed);
    }

    @Override
    protected void onPause() {
        super.onPause();
		if (!paused){
			wasPlaying = true;
			paused = true;
			playPause.setBackgroundResource(R.drawable.icon_av_play);
			if (mTrack != null) {
			    mTrack.pause();
			}
		}
   }

    @Override
    protected void onResume() {
        super.onPause();
		if ((mTrack != null) && wasPlaying) {
	   		wasPlaying = false;
			paused = false;
			playPause.setBackgroundResource(R.drawable.icon_av_pause);
		    mTrack.play();
		}
	}

}
