package BPpackage;
 
/*
 * Subset.java is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * R. Earle Harris (evsiz@this-voice.org) copyrighted 2014
 *
 */


import android.app.AlertDialog;
import android.app.Dialog;
import android.app.ListActivity;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Bundle;
import android.os.Environment;
import android.os.Handler;
import android.text.InputType;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.view.MenuItem;
import android.view.View.OnClickListener;
import android.view.View;
import android.view.Window;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.AdapterView.OnItemLongClickListener;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.Toast;
import java.io.File;
import java.lang.Runnable;
import java.lang.String;
import java.net.URLDecoder;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class Subset extends ListActivity {

	public Map<String, String> dbs = new HashMap<String, String>();
	public Map<String, String> sets = new HashMap<String, String>();
	public List<String> nameList = null;
	public PRAFileHandler fhandler = new PRAFileHandler(this);
	public String prefix = "set";
	public String subsetName = "Subset";
	public String setName = "";
	public String currentSet = "";
	public String sep = "\t"; // must be invalid URL char
	public String[] Entries;
	public TextView title;
	public URLDecoder decoder = new URLDecoder();
	public final static int ITEM = 0;


	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);

		Intent i = getIntent();
		currentSet= i.getStringExtra("SET"); //filename: prefix+setName
		setName = decoder.decode(currentSet.replace(prefix, ""));

		setContentView(R.layout.activity_subset);
		title = (TextView) findViewById(R.id.title);
	}

	@Override
	public void onResume() {
		super.onResume();
		buildList();
		setListAdapter(new ArrayAdapter<String>(this, R.layout.pra_list_item, Entries));
		EdgeEffectListView listView = (EdgeEffectListView) getListView();
		listView.setTextFilterEnabled(true);
		final Context c = this;
		listView.setOnItemClickListener(new OnItemClickListener() {
			@Override
			public void onItemClick(AdapterView<?> parent, View view,
					int position, long id) {
				String name = (String) ((TextView) view).getText();
				String data = dbs.get(name);
				Intent intent = new Intent(c, Result.class);
				intent.putExtra("DATA", data);
				startActivityForResult(intent, ITEM);
			}
		});
		title.setText(getResources().getString(R.string.set) + ": "+ setName);

		final String[] menu_array = { 
			"Remove", 
			"Rename", 
			"Move", 
		};

		listView.setOnItemLongClickListener(new OnItemLongClickListener() {
		 
		    @Override 
			public boolean onItemLongClick(AdapterView parentView, View view, int position, long id) {
				final String name = ((TextView) view).getText().toString();
				final String data = dbs.get(name); // full path name in HashMap dbs

				LayoutInflater inflater = getLayoutInflater();
				final ArrayList<String> list = new ArrayList<String>();
				for (int i = 0; i < menu_array.length; ++i) {
					list.add(menu_array[i]);
				}
				
				AlertDialog.Builder builder = new AlertDialog.Builder(c);
				final ArrayAdapter adapter = new ArrayAdapter(c, R.layout.pra_list_item, list);
				builder.setView(inflater.inflate(R.layout.list_context_menu, null))
					.setAdapter(adapter, new DialogInterface.OnClickListener() {
					@Override
					public void onClick(DialogInterface dialog, int which) {
						String result = (String) adapter.getItem(which);
						if (result.matches("Remove")){
							final Dialog dialog1 = new Dialog(c);
							dialog1.requestWindowFeature(Window.FEATURE_NO_TITLE);
							dialog1.setContentView(R.layout.alert_two);
							TextView t = (TextView) dialog1.findViewById(R.id.dTitle);
							t.setText("Remove "+subsetName);
							TextView m = (TextView) dialog1.findViewById(R.id.dMessage);
							m.setText(name);

							Button pos = (Button) dialog1.findViewById(R.id.dPos);
							pos.setText("Remove");
							pos.setOnClickListener(new OnClickListener() {
								@Override
								public void onClick(View v) {
									fhandler.removeLineByToken0(currentSet, name, sep);
									dialog1.dismiss();
									onResume();
								}
								});
							
							Button neg = (Button) dialog1.findViewById(R.id.dNeg);
							neg.setText("Cancel");
							neg.setOnClickListener(new OnClickListener() {
								@Override
								public void onClick(View v) {
									dialog1.dismiss();
								}
								});
							
							dialog1.show();
							
						} else if (result.matches("Rename")){
							final Dialog dialog2 = new Dialog(c);
							dialog2.requestWindowFeature(Window.FEATURE_NO_TITLE);
							dialog2.setContentView(R.layout.alert_two_edit);
							TextView t = (TextView) dialog2.findViewById(R.id.dTitle);
							t.setText("Rename "+subsetName);
							TextView m = (TextView) dialog2.findViewById(R.id.dMessage);
							m.setText("Enter new name.\nCancel aborts.");
							final EditText e = (EditText) dialog2.findViewById(R.id.dEdit);
							e.setInputType(InputType.TYPE_CLASS_TEXT);
							e.setText(name);
							Button pos = (Button) dialog2.findViewById(R.id.dPos);
							pos.setText("Set Name");
							pos.setOnClickListener(new OnClickListener() {
								@Override
								public void onClick(View v) {
									String newName = e.getText().toString();
									newName = newName.replaceAll("[^0-9A-Za-z\\s\\.\\-\\']", "");
									String line = data.replace(name, newName);
									fhandler.removeLineByToken0(currentSet, name, sep);
									fhandler.writeUniqLineByToken0(currentSet, line, sep);

									newName = newName.replaceAll("[^A-Za-z]", "");
									String oldName = name.replaceAll("[^A-Za-z]", "");
									File sdCard = Environment.getExternalStorageDirectory();
									String oldf = sdCard.getAbsolutePath() +"/SetMetMojo/" + oldName + ".txt"; 
									String newf = sdCard.getAbsolutePath() +"/SetMetMojo/" + newName + ".txt"; 
									fhandler.move(oldf, newf);

									dialog2.dismiss();
									onResume();
								}
								});
		
							Button neg = (Button) dialog2.findViewById(R.id.dNeg);
							neg.setText("Cancel");
							neg.setOnClickListener(new OnClickListener() {
								@Override
								public void onClick(View v) {
									dialog2.dismiss();
								}
								});
							
							dialog2.show();
						} else if (result.matches("Move")){
							String fname = "";
							String title = "";
							String[] tokens;
							File internal = getFilesDir();
							File[] files = internal.listFiles();
							List<String> alist = new ArrayList<String>();
							for (File inFile : files) {
								fname = inFile.toString();
								tokens	= fname.split("/");
								fname = tokens[tokens.length - 1];
								if ((fname.startsWith(prefix)) && (!fname.matches(currentSet))){
									title = decoder.decode(fname.replace(prefix, ""));
									alist.add(title);
									sets.put(title, fname);
								}
							}

							Collections.sort(alist);
							String[] list = new String[alist.size()];
							alist.toArray(list);
							final String[] listf = list;

							AlertDialog.Builder b = new AlertDialog.Builder(c);
							final ArrayAdapter adapter = new ArrayAdapter(c, R.layout.pra_list_item, list);
							b.setAdapter(adapter, new DialogInterface.OnClickListener() {
									 public void onClick(DialogInterface dialog, int which) {
										 String dest = sets.get(listf[which]);
										 fhandler.removeLineByToken0(currentSet, name, sep);
										 fhandler.writeUniqLineByToken0(dest, data, sep);
										 onResume();
									 }
								 });
							LayoutInflater inflater = getLayoutInflater();
							View vw = inflater.inflate(R.layout.titlemove, null);
							b.setCustomTitle(vw);
							b.create();
							b.show();
						}
						
					}
						})
					.create()
					.show();
				return true;
			}
			});
	}




	// line of data: "Name of Data"\t"data (can have tabs)
	public void buildList() {
		nameList = new ArrayList<String>();
		String[] file = fhandler.getFileAsArray(currentSet);
		for (String s : file) {
			String[] t = s.split(sep);
			nameList.add(t[0]); //"Name of Data"
			dbs.put(t[0], s);     //key is "Name of Data", value is entire line of data
		}

		Collections.sort(nameList);
		dbs.put("New "+subsetName, "new"); // leave here to sync array indices
		nameList.add("New "+subsetName);

		Entries = new String[nameList.size()];
		nameList.toArray(Entries);

	}



	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent i) {
		if (requestCode == ITEM) {
			if (resultCode == RESULT_OK) {
				String data = i.getStringExtra("DATA");
				String track = i.getStringExtra("TRACK");
				String state = i.getStringExtra("STATE");
				fhandler.writeUniqLineByToken0(currentSet, data, sep);
				onResume();
			} else {
				onResume();
			}
		} 
	}


	public void toaster(String text, int length) {
		Toast t = Toast.makeText(this, text, length);
		t.setGravity(Gravity.CENTER, 0, 0);
		t.show();
	}


	private boolean doubleBackPressedOnce = false;

	@Override
	public void onBackPressed() {
		if (doubleBackPressedOnce) {
			Intent intent = new Intent();
			setResult(RESULT_OK, intent); 
			finish();
		}
		doubleBackPressedOnce = true;
		Toast.makeText(this, R.string.exit_bkbtn, Toast.LENGTH_SHORT).show();
		new Handler().postDelayed(new Runnable() {

			@Override
			public void run() {
				doubleBackPressedOnce = false;
			}
		}, 2000);
	}

}
