package BPpackage;
 
/*
 * NetworkService.java is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * R. Earle Harris (evsiz@this-voice.org) copyrighted 2014
 *
 */


import java.lang.reflect.Field;
import java.lang.reflect.Method;

import android.app.Notification;
import android.app.PendingIntent;
import android.app.Service;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.content.SharedPreferences;
import android.net.ConnectivityManager;
import android.net.wifi.WifiManager;
import android.os.Build;
import android.os.Handler;
import android.os.IBinder;
import android.os.Message;
import android.os.Messenger;
import android.preference.PreferenceManager;
import android.support.v4.app.NotificationCompat;
import android.telephony.TelephonyManager;

public class NetworkService extends Service {
	
	
	/**
	 * Messenger
	 */
	final Messenger mMessenger = new Messenger(new IncomingHandler());

	static final int MSG_DATA_1 = 1;
	static final int MSG_DATA_0 = 2;
	static final int MSG_WIFI_1 = 3;
	static final int MSG_WIFI_0 = 4;

	static boolean killData = false;
	static boolean killWifi = false;

	static class IncomingHandler extends Handler {
		@Override
		public void handleMessage(Message msg) {
			switch (msg.what) {
			case MSG_DATA_1:
				killData = true;
				break;
			case MSG_DATA_0:
				killData = false;
				break;
			case MSG_WIFI_1:
				killWifi = true;
				break;
			case MSG_WIFI_0:
				killWifi = false;
				break;
			}
		}
	}

	/**
	 * BroadcastReceiver
	 */
	private IntentFilter screenOff = new IntentFilter(Intent.ACTION_SCREEN_OFF);

	private BroadcastReceiver mScreenReceiver = new BroadcastReceiver() {

		@Override
		public void onReceive(Context context, Intent intent) {
			if (!killData && !killWifi) {
				return;
			}			

			if (killData) {
				// try-catch contents by rIHaN JiTHiN on stackoverflow.com,
				// bless his heart
				try {
					int bv = Build.VERSION.SDK_INT;
					if (bv == Build.VERSION_CODES.FROYO) {
						Method dataConnSwitchmethod;
						Class<?> telephonyManagerClass;
						Object ITelephonyStub;
						Class<?> ITelephonyClass;
						TelephonyManager telephonyManager = (TelephonyManager) context
								.getSystemService(Context.TELEPHONY_SERVICE);
						telephonyManagerClass = Class.forName(telephonyManager
								.getClass().getName());
						Method getITelephonyMethod = telephonyManagerClass
								.getDeclaredMethod("getITelephony");
						getITelephonyMethod.setAccessible(true);
						ITelephonyStub = getITelephonyMethod
								.invoke(telephonyManager);
						ITelephonyClass = Class.forName(ITelephonyStub
								.getClass().getName());
						dataConnSwitchmethod = ITelephonyClass
								.getDeclaredMethod("disableDataConnectivity");
						dataConnSwitchmethod.setAccessible(true);
						dataConnSwitchmethod.invoke(ITelephonyStub);
					} else {
						final ConnectivityManager conman = (ConnectivityManager) context
								.getSystemService(Context.CONNECTIVITY_SERVICE);
						final Class<?> conmanClass = Class.forName(conman
								.getClass().getName());
						final Field iConnectivityManagerField = conmanClass
								.getDeclaredField("mService");
						iConnectivityManagerField.setAccessible(true);
						final Object iConnectivityManager = iConnectivityManagerField
								.get(conman);
						final Class<?> iConnectivityManagerClass = Class
								.forName(iConnectivityManager.getClass()
										.getName());
						final Method setMobileDataEnabledMethod = iConnectivityManagerClass
								.getDeclaredMethod("setMobileDataEnabled",
										Boolean.TYPE);
						setMobileDataEnabledMethod.setAccessible(true);
						setMobileDataEnabledMethod.invoke(iConnectivityManager,
								false);
					}
				} catch (Exception e) {
					;// empty
				}
			}

			if (killWifi) {
				WifiManager wifi = (WifiManager) getSystemService(Context.WIFI_SERVICE);
				wifi.setWifiEnabled(false);
			}

			System.gc();
		}
	};

	/**
	 * Android States
	 */

	@Override
	public IBinder onBind(Intent intent) {
		return mMessenger.getBinder();
	}

	@Override
	public int onStartCommand(Intent intent, int flags, int startId) {
		SharedPreferences prefs = PreferenceManager
				.getDefaultSharedPreferences(getBaseContext());

		boolean state = prefs.getBoolean("data_checkbox", false);
		if (state) {
			killData = true;
		} else {
			killData = false;
		}
		state = prefs.getBoolean("wifi_checkbox", false);
		if (state) {
			killWifi = true;
		} else {
			killWifi = false;
		}
		
		Intent notificationIntent = new Intent(this, NetworkService.class);
		PendingIntent mPendingIntent = PendingIntent.getActivity(this, 0, notificationIntent, 0);
		NotificationCompat.Builder notebld = new NotificationCompat.Builder(this)
			.setContentTitle("Network Juju")
			.setContentText("Poor Richard's Alchemy")
			.setSmallIcon(R.drawable.icon)
			.setContentIntent(mPendingIntent);
		Notification note = notebld.build();

		startForeground(1, note);
		
		return START_STICKY;
	}

	@Override
	public void onCreate() {
		registerReceiver(mScreenReceiver, screenOff);
		super.onCreate();
	}

	@Override
	public void onDestroy() {
		super.onDestroy();
		unregisterReceiver(mScreenReceiver);
	}
}
