package BPpackage;
 
/*
 * TimerService.java is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * R. Earle Harris (evsiz@this-voice.org) copyrighted 2014
 *
 */


import android.app.Service;
import android.content.Context;
import android.content.Intent;
import android.media.MediaPlayer.OnCompletionListener;
import android.media.MediaPlayer;
import android.net.Uri;
import android.os.Binder;
import android.os.CountDownTimer;
import android.os.IBinder;
import android.support.v4.content.LocalBroadcastManager;
import java.lang.Exception;

public class TimerService extends Service {

	public static String UPDATE_TIMER_INTENT = "update_timer_intent";
	public static String TIMER_FINISHED_INTENT = "timer_finished_intent";
	
	CountDownTimer timer;

	// returns the instance of this Service so the clients can call public methods
    public class LocalBinder extends Binder {
    	TimerService getService() {
            return TimerService.this;
        }
    }
	
    // This is the object given to clients that receives interactions
    private final IBinder mBinder = new LocalBinder();
	
    @Override
    public IBinder onBind(Intent intent) {
    	return mBinder;
    }
	

    /* Methods for clients */
    public void startCountdown(int timerLength) {
		long duration;
		if (timerLength == 0){
			duration = 10 * 1000;
		} else {
			duration = timerLength * 1000;
		} 
    	//  timerLength min * 60 secs * 1000 ms/sec with one tick every 1/2 sec (500 millisecs)
    	timer = new CountDownTimer(duration, 500) {
    		
    		public void onTick(long msUntilFinished) {
				// send a local broadcast to the client
    	    	Intent timerIntent = new Intent(TimerService.UPDATE_TIMER_INTENT);
    	    	timerIntent.putExtra("timeRemainingMs", msUntilFinished); // time left in milliseconds
    	    	LocalBroadcastManager.getInstance(TimerService.this).sendBroadcast(timerIntent);
			}

			public void onFinish() {
				// send a local broadcast to the client
    	    	Intent timerIntent = new Intent(TimerService.TIMER_FINISHED_INTENT);
    	    	LocalBroadcastManager.getInstance(TimerService.this).sendBroadcast(timerIntent);
			}
    	};
    	
    	// start the countdown
    	timer.start();
    }

    
    public void stopCountdown() {
    	if (timer != null) {
    		timer.cancel();	
    	}
    }
	
}
